<?php

/**
 * @file
 * Theme settings file for the OCIO Omega Base theme.
 */

require_once dirname(__FILE__) . '/template.php';

/**
 * Implements hook_form_FORM_alter().
 */
function ocio_omega_base_form_system_theme_settings_alter(&$form, $form_state) {
  // You can use this hook to append your own theme settings to the theme
  // settings form for your subtheme. You should also take a look at the
  // 'extensions' concept in the Omega base theme.
  $form['ocio_omega'] = array(
    '#type' => 'fieldset',
    '#title' => t('Theme Customization'),
    '#description' => t('Customize the look and feel of the site.'),
    'ocio_omega_breadcrumb' => array(
      '#type'  => 'checkbox',
      '#title' => t('Show breadcrumbs'),
      '#default_value' => theme_get_setting('ocio_omega_breadcrumb'),
    ),
    'ocio_omega_color_navbar' => array(
      '#type'  => 'radios',
      '#title' => t('OSU Nav Bar'),
      '#default_value' => theme_get_setting('ocio_omega_color_navbar'),
      '#options' => ocio_omega_base_generate_color_swatches(
        array(
          'lt-gray' => t('Light Gray'),
          'dk-gray' => t('Dark Gray'),
        )
      ),
    ),
    'ocio_omega_color_masthead' => array(
      '#type' => 'radios',
      '#title' => t('Masthead'),
      '#default_value' => theme_get_setting('ocio_omega_color_masthead'),
      '#options' => ocio_omega_base_generate_color_swatches(
        array(
          'white' => t('White'),
          'lt-gray' => t('Light Gray'),
          'dk-gray' => t('Dark Gray'),
        )
      )
    ),
    'ocio_omega_color_menu' => array(
      '#type' => 'radios',
      '#title' => t('Menu'),
      '#default_value' => theme_get_setting('ocio_omega_color_menu'),
      '#options' => ocio_omega_base_generate_color_swatches(
        array(
          'white' => t('White'),
          'lt-gray' => t('Light Gray'),
          'md-gray' => t('Mid Gray'),
          'dk-gray' => t('Dark Gray'),
          'black' => t('Black'),
          'red' => t('Red'),
        )
      )
    ),
  );

  $form['#attached']['css'][] = drupal_get_path('theme', 'ocio_omega_base') . '/css/ocio-omega-base.settings.css';
  $form['#validate'][] = 'ocio_omega_base_form_system_theme_settings_validate';
}

function ocio_omega_base_form_system_theme_settings_validate(&$form, &$form_state) {
  
  if (!empty($form['ocio_omega']['ocio_omega_color_navbar'])) {  
	  if ($form_state['values']['ocio_omega_color_navbar'] == 'dk-gray' && $form_state['values']['ocio_omega_color_masthead'] == 'dk-gray') {
	    form_set_error('ocio_omega_color_masthead', t('Dark masthead cannot be used with dark navbar.'));
	    $form['ocio_omega']['ocio_omega_color_masthead']['dk-gray']['#attributes']['class'][] = 'form-radio-error';
	  }
	}
}


/**
 * Generate Color swatches for settings
 */

function ocio_omega_base_generate_color_swatches($options = array()) {
  foreach ($options as $name => $title) {
    $option = '<span class="' . $name . '-option swatch-panel">';
    $option .= '<span class="label">' . $title . '</span>';
    $option .= '<div class="swatch ' . $name . '"></div>';
    $option .= '</span>';
    $options[$name] = $option;
  }
  return $options;
}
